==> claromentis-framework-9.6.6-26891208.zip: web/intranet/infocapture/classes/Event/NoteChangeEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
use HDIssue;
use HDProject;
use ICNote;
class NoteChangeEvent extends Event
{
    
    
    
    
    protected $note;
    
    
    
    
    protected $previous;
    protected $message = '';
    
    
    
    
    protected $issue;
    
    
    
    
    protected $project;
    public function __construct(HDProject $project, HDIssue $issue, ICNote $_42f4f5c47629333345a44de2ac08c8b4, ?ICNote $_ee1c4cef8785a744408faf37f4e50100)
    {
        $this->note = $_42f4f5c47629333345a44de2ac08c8b4;
        $this->previous = $_ee1c4cef8785a744408faf37f4e50100;
        $this->issue = $issue;
        $this->project = $project;
    }
    
    
    
    
    public function GetNote() : ICNote
    {
        return $this->note;
    }
    
    
    
    
    public function SetNote(ICNote $_42f4f5c47629333345a44de2ac08c8b4) : void
    {
        $this->note = $_42f4f5c47629333345a44de2ac08c8b4;
    }
    
    
    
    
    public function GetPrevious() : ?ICNote
    {
        return $this->previous;
    }
    
    
    
    
    public function SetPrevious(?ICNote $_ee1c4cef8785a744408faf37f4e50100) : void
    {
        $this->previous = $_ee1c4cef8785a744408faf37f4e50100;
    }
    
    
    
    
    public function GetMessage() : string
    {
        return $this->message;
    }
    
    
    
    
    public function SetMessage(string $message) : void
    {
        $this->message = $message;
    }
    
    
    
    
    public function GetIssue() : HDIssue
    {
        return $this->issue;
    }
    
    
    
    
    public function SetIssue(HDIssue $issue) : void
    {
        $this->issue = $issue;
    }
    
    
    
    
    public function GetProject() : HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function SetProject(HDProject $project) : void
    {
        $this->project = $project;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/infocapture/classes/Event/NoteChangeEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
use HDIssue;
use HDProject;
use ICNote;
class NoteChangeEvent extends Event
{
    
    
    
    
    protected $note;
    
    
    
    
    protected $previous;
    protected $message = '';
    
    
    
    
    protected $issue;
    
    
    
    
    protected $project;
    public function __construct(HDProject $project, HDIssue $issue, ICNote $_42f4f5c47629333345a44de2ac08c8b4, ?ICNote $_ee1c4cef8785a744408faf37f4e50100)
    {
        $this->note = $_42f4f5c47629333345a44de2ac08c8b4;
        $this->previous = $_ee1c4cef8785a744408faf37f4e50100;
        $this->issue = $issue;
        $this->project = $project;
    }
    
    
    
    
    public function GetNote() : ICNote
    {
        return $this->note;
    }
    
    
    
    
    public function SetNote(ICNote $_42f4f5c47629333345a44de2ac08c8b4) : void
    {
        $this->note = $_42f4f5c47629333345a44de2ac08c8b4;
    }
    
    
    
    
    public function GetPrevious() : ?ICNote
    {
        return $this->previous;
    }
    
    
    
    
    public function SetPrevious(?ICNote $_ee1c4cef8785a744408faf37f4e50100) : void
    {
        $this->previous = $_ee1c4cef8785a744408faf37f4e50100;
    }
    
    
    
    
    public function GetMessage() : string
    {
        return $this->message;
    }
    
    
    
    
    public function SetMessage(string $message) : void
    {
        $this->message = $message;
    }
    
    
    
    
    public function GetIssue() : HDIssue
    {
        return $this->issue;
    }
    
    
    
    
    public function SetIssue(HDIssue $issue) : void
    {
        $this->issue = $issue;
    }
    
    
    
    
    public function GetProject() : HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function SetProject(HDProject $project) : void
    {
        $this->project = $project;
    }
}
